@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "accountmanager.h"
+#include "connection.h"
+#include "job/validateinviteserverjob.h"
 #include "localdatabase/localdatabaseutils.h"
 #include "managerdatapaths.h"
 #include "model/rocketchataccountfilterproxymodel.h"
@@ -15,6 +17,7 @@
 #include "rocketchataccountsettings.h"
 #include "ruqola_debug.h"
 
+#include "ruqola.h"
 #include "ruqola_sound_debug.h"
 #include "ruqolaglobalconfig.h"
 #include "utils.h"
@@ -23,6 +26,7 @@
 #include "activities/activitiesmanager.h"
 #endif
 #include <KLocalizedString>
+#include <KNotification>
 #include <QDir>
 #include <QDirIterator>
 #include <QSettings>
@@ -842,21 +846,39 @@ void AccountManager::changeEnableState(RocketChatAccount *account, bool enabled)
     }
 }
 
+void AccountManager::addInvitedAccount(const AccountManagerInfo &info)
+{
+    auto job = new ValidateInviteServerJob(this);
+    job->setInfo(info);
+    connect(job, &ValidateInviteServerJob::tokenIsInvalid, this, []() {
+        auto notification = new KNotification(QStringLiteral("Invite-Account-Invalid"), KNotification::CloseOnTimeout);
+        notification->setTitle(i18n("Invalid invite token"));
+        notification->setText(i18n("Invite Token is invalid. Creating account canceled."));
+        notification->sendEvent();
+    });
+    connect(job, &ValidateInviteServerJob::tokenIsValid, this, [](const AccountManager::AccountManagerInfo &info) {
+        Q_EMIT Ruqola::self() -> addInviteServer(info);
+    });
+    job->start();
+}
+
 void AccountManager::addAccount(const AccountManagerInfo &info)
 {
     const QString newAccountName = Utils::createUniqueAccountName(accountsName(), info.accountName);
     auto account = new RocketChatAccount();
     account->setAccountName(newAccountName);
     account->setServerUrl(info.serverUrl);
-    account->setAccountEnabled(info.enabled);
-    account->setActivities(info.activitiesSettings.activities);
-    account->setActivityEnabled(info.activitiesSettings.enabled);
+    auto settings = account->settings();
+    settings->setAccountEnabled(info.enabled);
+    settings->setActivities(info.activitiesSettings.activities);
+    settings->setActivityEnabled(info.activitiesSettings.enabled);
+    settings->setInviteToken(info.inviteToken);
     if (info.authMethodType == AuthenticationManager::AuthMethodType::Password) {
-        account->setUserName(info.userName);
-        account->setPassword(info.password);
+        settings->setUserName(info.userName);
+        settings->setPassword(info.password);
     } else if (info.authMethodType == AuthenticationManager::AuthMethodType::PersonalAccessToken) {
-        account->setAuthToken(info.token);
-        account->setUserId(info.userId);
+        settings->setAuthToken(info.token);
+        settings->setUserId(info.userId);
     } else {
         // TODO for other authMethodType ?
         // google used ?
@@ -864,7 +886,7 @@ void AccountManager::addAccount(const AccountManagerInfo &info)
         // Gitlab ?
         // GitHub ?
     }
-    account->setAuthMethodType(info.authMethodType);
+    settings->setAuthMethodType(info.authMethodType);
     if (info.enabled) {
         connectToAccount(account);
     }
@@ -875,18 +897,19 @@ void AccountManager::modifyAccount(const AccountManagerInfo &info)
 {
     RocketChatAccount *account = mRocketChatAccountModel->account(info.accountName);
     if (account) {
-        account->setDisplayName(info.displayName);
+        auto settings = account->settings();
+        settings->setDisplayName(info.displayName);
         account->setServerUrl(info.serverUrl);
-        account->setAccountEnabled(info.enabled);
-        account->setAuthMethodType(info.authMethodType);
-        account->setActivities(info.activitiesSettings.activities);
-        account->setActivityEnabled(info.activitiesSettings.enabled);
+        settings->setAccountEnabled(info.enabled);
+        settings->setAuthMethodType(info.authMethodType);
+        settings->setActivities(info.activitiesSettings.activities);
+        settings->setActivityEnabled(info.activitiesSettings.enabled);
         if (info.authMethodType == AuthenticationManager::AuthMethodType::Password) {
-            account->setUserName(info.userName);
+            settings->setUserName(info.userName);
             // TODO add password ???
         } else if (info.authMethodType == AuthenticationManager::AuthMethodType::PersonalAccessToken) {
-            account->setAuthToken(info.token);
-            account->setUserId(info.userId);
+            settings->setAuthToken(info.token);
+            settings->setUserId(info.userId);
         } else {
             // TODO ????
         }
@@ -1010,7 +1033,7 @@ QList<AccountManager::AccountDisplayInfo> AccountManager::accountDisplayInfoSort
         auto account = index.data(RocketChatAccountModel::Account).value<RocketChatAccount *>();
         if (account->accountEnabled()) {
             AccountManager::AccountDisplayInfo info;
-            info.name = account->displayName();
+            info.name = account->settings()->displayName();
             info.icon = Utils::iconFromAccount(account);
             lst.append(std::move(info));
         }
@@ -1020,19 +1043,20 @@ QList<AccountManager::AccountDisplayInfo> AccountManager::accountDisplayInfoSort
 
 QDebug operator<<(QDebug d, const AccountManager::AccountManagerInfo &t)
 {
-    d.space() << " authenticationInfos" << t.authenticationInfos;
-    d.space() << " displayName" << t.displayName;
-    d.space() << " accountName" << t.accountName;
-    d.space() << " userName" << t.userName;
-    d.space() << " serverUrl" << t.serverUrl;
-    d.space() << " token" << t.token;
-    d.space() << " userId" << t.userId;
-    d.space() << " authMethodType" << t.authMethodType;
-    d.space() << " canResetPassword" << t.canResetPassword;
-    d.space() << " enabled" << t.enabled;
-    d.space() << " canRegisterAccount" << t.canRegisterAccount;
-    d.space() << " activities" << t.activitiesSettings.activities;
-    d.space() << " activities enabled" << t.activitiesSettings.enabled;
+    d.space() << "authenticationInfos" << t.authenticationInfos;
+    d.space() << "displayName" << t.displayName;
+    d.space() << "accountName" << t.accountName;
+    d.space() << "userName" << t.userName;
+    d.space() << "serverUrl" << t.serverUrl;
+    d.space() << "token" << t.token;
+    d.space() << "userId" << t.userId;
+    d.space() << "authMethodType" << t.authMethodType;
+    d.space() << "canResetPassword" << t.canResetPassword;
+    d.space() << "enabled" << t.enabled;
+    d.space() << "canRegisterAccount" << t.canRegisterAccount;
+    d.space() << "activities" << t.activitiesSettings.activities;
+    d.space() << "activities enabled" << t.activitiesSettings.enabled;
+    d.space() << "invite token" << t.inviteToken;
     return d;
 }
 
