@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -77,6 +77,8 @@ public:
             ContactWrite,
             ContactRead,
             EmailSend,
+            RoleRead,
+            RoleWrite,
         };
         [[nodiscard]] bool operator==(const Permission &other) const;
         [[nodiscard]] static PermissionType convertStringToPermissionType(const QString &str);
@@ -153,6 +155,10 @@ public:
     [[nodiscard]] AppsMarketPlaceInstalledInfo installedInfo() const;
     void setInstalledInfo(const AppsMarketPlaceInstalledInfo &newInstalledInfo);
 
+    void clearInstalledInfo();
+    void changeApplicationStatus(const QString &str);
+    [[nodiscard]] QString permissionsDescription() const;
+
 private:
     LIBRUQOLACORE_NO_EXPORT void parsePrincingPlan(const QJsonArray &array);
     LIBRUQOLACORE_NO_EXPORT void parseAuthor(const QJsonObject &authorObject);
