@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ void EmojiManagerTest::shouldHaveDefaultValue()
 {
     EmojiManager manager(nullptr);
     QVERIFY(manager.serverUrl().isEmpty());
-    QCOMPARE(manager.count(), 3671);
+    QCOMPARE(manager.count(), 3820);
     QVERIFY(manager.customEmojiList().isEmpty());
 }
 
@@ -33,7 +33,7 @@ void EmojiManagerTest::shouldParseEmoji_data()
 {
     QTest::addColumn<QString>("name");
     QTest::addColumn<int>("number");
-    QTest::addRow("emojiparent") << QStringLiteral("emojiparent") << 3678;
+    QTest::addRow("emojiparent") << QStringLiteral("emojiparent") << 3827;
 }
 
 void EmojiManagerTest::shouldParseEmoji()
@@ -58,7 +58,7 @@ void EmojiManagerTest::shouldDeleteEmojiCustom_data()
         QList<CustomEmoji> emojiList;
         CustomEmoji val;
         val.setName(QStringLiteral("kdab"));
-        val.setIdentifier(QByteArrayLiteral("RyBauhQqnoE5WeJvZ"));
+        val.setIdentifier("RyBauhQqnoE5WeJvZ"_ba);
         val.setExtension(QStringLiteral("png"));
         val.setEmojiIdentifier(QStringLiteral(":kdab:"));
         val.setUpdatedAt(1529303015003);
@@ -66,7 +66,7 @@ void EmojiManagerTest::shouldDeleteEmojiCustom_data()
 
         CustomEmoji val1;
         val1.setName(QStringLiteral("vader"));
-        val1.setIdentifier(QByteArrayLiteral("fAiQmJnJPAaEFmps6"));
+        val1.setIdentifier("fAiQmJnJPAaEFmps6"_ba);
         val1.setExtension(QStringLiteral("png"));
         val1.setEmojiIdentifier(QStringLiteral(":vader:"));
         val1.setUpdatedAt(1560497261506);
@@ -76,20 +76,20 @@ void EmojiManagerTest::shouldDeleteEmojiCustom_data()
         QList<CustomEmoji> emojiListAfterDeleting;
         emojiListAfterDeleting.append(val1);
 
-        QTest::addRow("delete1") << QStringLiteral("emojiparent2") << 3673 << QStringLiteral("emojicustomdelete1") << emojiList << emojiListAfterDeleting;
+        QTest::addRow("delete1") << QStringLiteral("emojiparent2") << 3822 << QStringLiteral("emojicustomdelete1") << emojiList << emojiListAfterDeleting;
     }
     {
         QList<CustomEmoji> emojiList;
         CustomEmoji val;
         val.setName(QStringLiteral("kdab"));
-        val.setIdentifier(QByteArrayLiteral("RyBauhQqnoE5WeJvZ"));
+        val.setIdentifier("RyBauhQqnoE5WeJvZ"_ba);
         val.setExtension(QStringLiteral("png"));
         val.setEmojiIdentifier(QStringLiteral(":kdab:"));
         val.setUpdatedAt(1529303015003);
 
         CustomEmoji val1;
         val1.setName(QStringLiteral("vader"));
-        val1.setIdentifier(QByteArrayLiteral("fAiQmJnJPAaEFmps6"));
+        val1.setIdentifier("fAiQmJnJPAaEFmps6"_ba);
         val1.setExtension(QStringLiteral("png"));
         val1.setEmojiIdentifier(QStringLiteral(":vader:"));
         val1.setUpdatedAt(1560497261506);
@@ -98,7 +98,7 @@ void EmojiManagerTest::shouldDeleteEmojiCustom_data()
         emojiList.append(std::move(val));
         emojiList.append(std::move(val1));
         // We can't delete emoji which is not in liste.
-        QTest::addRow("delete2") << QStringLiteral("emojiparent2") << 3673 << QStringLiteral("emojicustomdelete2") << emojiList << emojiList;
+        QTest::addRow("delete2") << QStringLiteral("emojiparent2") << 3822 << QStringLiteral("emojicustomdelete2") << emojiList << emojiList;
     }
 }
 
@@ -135,14 +135,14 @@ void EmojiManagerTest::shouldAddEmojiCustom_data()
         QList<CustomEmoji> emojiList;
         CustomEmoji val;
         val.setName(QStringLiteral("kdab"));
-        val.setIdentifier(QByteArrayLiteral("RyBauhQqnoE5WeJvZ"));
+        val.setIdentifier("RyBauhQqnoE5WeJvZ"_ba);
         val.setExtension(QStringLiteral("png"));
         val.setEmojiIdentifier(QStringLiteral(":kdab:"));
         val.setUpdatedAt(1529303015003);
 
         CustomEmoji val1;
         val1.setName(QStringLiteral("vader"));
-        val1.setIdentifier(QByteArrayLiteral("fAiQmJnJPAaEFmps6"));
+        val1.setIdentifier("fAiQmJnJPAaEFmps6"_ba);
         val1.setExtension(QStringLiteral("png"));
         val1.setEmojiIdentifier(QStringLiteral(":vader:"));
         val1.setUpdatedAt(1560497261506);
@@ -154,13 +154,13 @@ void EmojiManagerTest::shouldAddEmojiCustom_data()
         QList<CustomEmoji> emojiListAfterDeleting = emojiList;
         CustomEmoji val2;
         val2.setName(QStringLiteral("ruqola"));
-        val2.setIdentifier(QByteArrayLiteral("HdN28k4PQ6J9xLkZ8"));
+        val2.setIdentifier("HdN28k4PQ6J9xLkZ8"_ba);
         val2.setExtension(QStringLiteral("png"));
         val2.setEmojiIdentifier(QStringLiteral(":ruqola:"));
         val2.setUpdatedAt(1631885946222);
         val2.setAliases({QStringLiteral(":roo:")});
         emojiList.append(std::move(val2));
-        QTest::addRow("emojiparent2") << QStringLiteral("emojiparent2") << 3673 << QStringLiteral("addemojicustom1") << emojiListAfterDeleting << emojiList;
+        QTest::addRow("emojiparent2") << QStringLiteral("emojiparent2") << 3822 << QStringLiteral("addemojicustom1") << emojiListAfterDeleting << emojiList;
     }
 }
 
@@ -202,14 +202,14 @@ void EmojiManagerTest::shouldUpdateEmojiCustom_data()
         QList<CustomEmoji> emojiList;
         CustomEmoji val;
         val.setName(QStringLiteral("kdab"));
-        val.setIdentifier(QByteArrayLiteral("RyBauhQqnoE5WeJvZ"));
+        val.setIdentifier("RyBauhQqnoE5WeJvZ"_ba);
         val.setExtension(QStringLiteral("png"));
         val.setEmojiIdentifier(QStringLiteral(":kdab:"));
         val.setUpdatedAt(1529303015003);
 
         CustomEmoji val1;
         val1.setName(QStringLiteral("vader"));
-        val1.setIdentifier(QByteArrayLiteral("fAiQmJnJPAaEFmps6"));
+        val1.setIdentifier("fAiQmJnJPAaEFmps6"_ba);
         val1.setExtension(QStringLiteral("png"));
         val1.setEmojiIdentifier(QStringLiteral(":vader:"));
         val1.setUpdatedAt(1560497261506);
@@ -221,14 +221,14 @@ void EmojiManagerTest::shouldUpdateEmojiCustom_data()
         QList<CustomEmoji> emojiListAfterDeleting;
         CustomEmoji val2;
         val2.setName(QStringLiteral("ruqola"));
-        val2.setIdentifier(QByteArrayLiteral("RyBauhQqnoE5WeJvZ"));
+        val2.setIdentifier("RyBauhQqnoE5WeJvZ"_ba);
         val2.setExtension(QStringLiteral("png"));
         val2.setEmojiIdentifier(QStringLiteral(":ruqola:"));
         val2.setUpdatedAt(1631885946222);
         val2.setAliases({QStringLiteral("rooss")});
         emojiListAfterDeleting.append(std::move(val));
         emojiListAfterDeleting.append(std::move(val2));
-        QTest::addRow("emojiparent2") << QStringLiteral("emojiparent2") << 3673 << QStringLiteral("updateemojicustom1") << emojiList << emojiList;
+        QTest::addRow("emojiparent2") << QStringLiteral("emojiparent2") << 3822 << QStringLiteral("updateemojicustom1") << emojiList << emojiList;
     }
 }
 
@@ -286,7 +286,7 @@ void EmojiManagerTest::shouldSupportUnicodeEmojis()
 
     QCOMPARE(manager.categories().count(), 9);
     QCOMPARE(manager.categories().at(0).category(), QStringLiteral("people"));
-    QCOMPARE(manager.emojisForCategory(QStringLiteral("people")).count(), 2031);
+    QCOMPARE(manager.emojisForCategory(QStringLiteral("people")).count(), 2158);
 }
 
 void EmojiManagerTest::shouldOrderUnicodeEmojis()
@@ -304,9 +304,9 @@ void EmojiManagerTest::shouldOrderUnicodeEmojis()
     auto it = std::find_if(list.begin(), list.end(), hasCategory(QStringLiteral("symbols")));
     QVERIFY(it != list.end());
     const TextEmoticonsCore::UnicodeEmoticon firstSymbol = *it;
-    QCOMPARE(firstSymbol.order(), 3063);
+    QCOMPARE(firstSymbol.order(), 3207);
     QCOMPARE(firstSymbol.category(), QStringLiteral("symbols"));
-    QCOMPARE(firstSymbol.identifier(), QStringLiteral(":heart:"));
+    QCOMPARE(firstSymbol.identifier(), QStringLiteral(":pink_heart:"));
 
     // Check what's the first emoji in the category "regional"
     it = std::find_if(list.begin(), list.end(), hasCategory(QStringLiteral("regional")));
