@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -197,7 +197,7 @@ void RocketChatAccountSettingsTest::shouldHaveDefaultValues()
     QVERIFY(chat.authToken().isEmpty());
     QCOMPARE(chat.serverUrl(), QStringLiteral("open.rocket.chat"));
     QVERIFY(chat.twoFactorAuthenticationCode().isEmpty());
-    QVERIFY(chat.accountEnabled());
+    QVERIFY(!chat.accountEnabled()); // Not valid => false
     QVERIFY(chat.displayName().isEmpty());
     QVERIFY(chat.activities().isEmpty());
 }
