@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "statusmodelfilterproxymodeltest.h"
 #include "model/statusmodelfilterproxymodel.h"
 #include <QTest>
-QTEST_MAIN(StatusModelFilterProxyModelTest)
+QTEST_GUILESS_MAIN(StatusModelFilterProxyModelTest)
 StatusModelFilterProxyModelTest::StatusModelFilterProxyModelTest(QObject *parent)
     : QObject(parent)
 {
