@@ -117,7 +117,8 @@ qint64 MessagesModel::lastTimestamp() const
 
 int MessagesModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
+    if (parent.isValid()) // flat model
+        return 0;
     return mAllMessages.size();
 }
 
@@ -258,9 +259,9 @@ QVariant MessagesModel::data(const QModelIndex &index, int role) const
         }
         return true; // show date at the top
     case MessagesModel::CanEditMessage:
-        return mRocketChatAccount->isMessageEditable(message); // && mRoom && mRoom->hasPermission(QStringLiteral("edit-message"));
+        return mRocketChatAccount && mRocketChatAccount->isMessageEditable(message); // && mRoom && mRoom->hasPermission(QStringLiteral("edit-message"));
     case MessagesModel::CanDeleteMessage:
-        return mRocketChatAccount->isMessageDeletable(message);
+        return mRocketChatAccount && mRocketChatAccount->isMessageDeletable(message);
     case MessagesModel::Starred:
         return message.isStarred();
     case MessagesModel::UsernameUrl: {
@@ -353,6 +354,10 @@ QVariant MessagesModel::data(const QModelIndex &index, int role) const
         return message.originalMessageOrAttachmentDescription();
     case MessagesModel::PrivateMessage:
         return message.privateMessage();
+    case MessagesModel::MessageReplies:
+        return messageReplies(message);
+    case MessagesModel::Unread:
+        return message.unread();
     }
 
     return {};
@@ -454,7 +459,9 @@ bool MessagesModel::setData(const QModelIndex &index, const QVariant &value, int
         return true;
     case MessagesModel::LocalTranslation:
         message.setLocalTranslation(value.toString());
-        Q_EMIT dataChanged(index, index, {MessagesModel::LocalTranslation});
+        // Make sure that we show translated message
+        message.setShowTranslatedMessage(true);
+        Q_EMIT dataChanged(index, index, {MessagesModel::ShowTranslatedMessage, MessagesModel::LocalTranslation});
         return true;
     }
     return false;
@@ -623,6 +630,14 @@ QString MessagesModel::threadMessagePreview(const QByteArray &threadMessageId) c
     return {};
 }
 
+bool MessagesModel::messageReplies(const Message &message) const
+{
+    if (mRocketChatAccount) {
+        return message.replies() && message.replies()->replies().contains(mRocketChatAccount->userId());
+    }
+    return false;
+}
+
 bool MessagesModel::threadMessageFollowed(const QByteArray &threadMessageId) const
 {
     if (!threadMessageId.isEmpty()) {
