@@ -1,11 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "notificationpreferencemodel.h"
 #include <KLocalizedString>
+using namespace Qt::Literals::StringLiterals;
 NotificationPreferenceModel::NotificationPreferenceModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -16,7 +17,8 @@ NotificationPreferenceModel::~NotificationPreferenceModel() = default;
 
 int NotificationPreferenceModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
+    if (parent.isValid()) // flat model
+        return 0;
     return mNotificationPreferenceList.count();
 }
 
@@ -43,25 +45,25 @@ void NotificationPreferenceModel::fillModel()
     {
         NotificationPreferenceInfo preferenceInfo;
         preferenceInfo.displayText = i18n("Default");
-        preferenceInfo.preference = QByteArrayLiteral("default");
+        preferenceInfo.preference = "default"_ba;
         mNotificationPreferenceList.append(std::move(preferenceInfo));
     }
     {
         NotificationPreferenceInfo preferenceInfo;
         preferenceInfo.displayText = i18n("All Messages");
-        preferenceInfo.preference = QByteArrayLiteral("all");
+        preferenceInfo.preference = "all"_ba;
         mNotificationPreferenceList.append(std::move(preferenceInfo));
     }
     {
         NotificationPreferenceInfo preferenceInfo;
         preferenceInfo.displayText = i18n("Mentions");
-        preferenceInfo.preference = QByteArrayLiteral("mentions");
+        preferenceInfo.preference = "mentions"_ba;
         mNotificationPreferenceList.append(std::move(preferenceInfo));
     }
     {
         NotificationPreferenceInfo preferenceInfo;
         preferenceInfo.displayText = i18n("Nothing");
-        preferenceInfo.preference = QByteArrayLiteral("nothing");
+        preferenceInfo.preference = "nothing"_ba;
         mNotificationPreferenceList.append(std::move(preferenceInfo));
     }
 }
