@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,6 +13,16 @@ class LIBRUQOLACORE_EXPORT UsersForRoomFilterProxyModel : public QSortFilterProx
 {
     Q_OBJECT
 public:
+    enum class FilterUserType : uint8_t {
+        All,
+        Online,
+        Offline,
+        Away,
+        Busy,
+        Owners,
+    };
+    Q_ENUM(FilterUserType);
+
     explicit UsersForRoomFilterProxyModel(QObject *parent = nullptr);
     ~UsersForRoomFilterProxyModel() override;
     void setFilterString(const QString &string);
@@ -23,7 +33,7 @@ public:
     [[nodiscard]] int total() const;
     [[nodiscard]] int numberOfUsers() const;
 
-    void setStatusType(const QString &statusType);
+    void setStatusType(UsersForRoomFilterProxyModel::FilterUserType statusType);
 
     void clearFilter();
 Q_SIGNALS:
@@ -35,5 +45,5 @@ protected:
     [[nodiscard]] bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
 private:
-    QString mStatusType;
+    UsersForRoomFilterProxyModel::FilterUserType mStatusType = UsersForRoomFilterProxyModel::FilterUserType::All;
 };
