@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "personalaccesstokeninfos.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_debug.h"
 
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 PersonalAccessTokenInfos::PersonalAccessTokenInfos() = default;
 
 QList<PersonalAccessTokenInfo> PersonalAccessTokenInfos::personalAccessTokenInfos() const
@@ -73,7 +73,12 @@ void PersonalAccessTokenInfos::parsePersonalAccessTokenInfos(const QJsonObject &
 QDebug operator<<(QDebug d, const PersonalAccessTokenInfos &t)
 {
     for (int i = 0, total = t.personalAccessTokenInfos().count(); i < total; ++i) {
-        d << t.personalAccessTokenInfos().at(i) << "\n";
+        d.space() << t.personalAccessTokenInfos().at(i) << "\n";
     }
     return d;
 }
+
+bool PersonalAccessTokenInfos::operator==(const PersonalAccessTokenInfos &other) const
+{
+    return personalAccessTokenInfos() == other.personalAccessTokenInfos();
+}
