@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,8 +30,8 @@ void IgnoreUserJobTest::shouldGenerateRequest()
 {
     IgnoreUserJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
-    job.setRoomId(QByteArrayLiteral("foo"));
-    job.setIgnoreUserId(QByteArrayLiteral("bla"));
+    job.setRoomId("foo"_ba);
+    job.setIgnoreUserId("bla"_ba);
     verifyAuthentication(&job, request);
     // TODO verify
     // TODO add ignore == false
