@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "channelremoveownerjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonDocument>
 #include <QJsonObject>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 ChannelRemoveOwnerJob::ChannelRemoveOwnerJob(QObject *parent)
     : ChannelGroupBaseJob(parent)
 {
@@ -37,11 +37,11 @@ void ChannelRemoveOwnerJob::onPostRequestResponse(const QString &replyErrorStrin
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("ChannelRemoveOwnerJob success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("ChannelRemoveOwnerJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT channelRemoveOwnerDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("ChannelRemoveOwnerJob problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("ChannelRemoveOwnerJob problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
