@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "runcommandjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 RunCommandJob::RunCommandJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -37,11 +37,12 @@ void RunCommandJob::onPostRequestResponse(const QString &replyErrorString, const
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("RunCommandJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("RunCommandJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT runCommandDone();
     } else {
+        Q_EMIT runCommandFailed(mRunCommandInfo);
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("RunCommandJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("RunCommandJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
@@ -55,19 +56,29 @@ void RunCommandJob::setRunCommandInfo(const RunCommandInfo &runCommandInfo)
     mRunCommandInfo = runCommandInfo;
 }
 
-RunCommandJob::RunCommandInfo RunCommandJob::parseString(const QString &str, const QByteArray &roomId, const QByteArray &tmid)
+bool RunCommandJob::RunCommandInfo::operator==(const RunCommandInfo &info) const
+{
+    return commandName == info.commandName && roomId == info.roomId && threadMessageId == info.threadMessageId && triggerId == info.triggerId
+        && params == info.params;
+}
+
+RunCommandJob::RunCommandInfo RunCommandJob::parseString(const QString &str, const QByteArray &roomId, const QByteArray &tmid, const QString &forceUuid)
 {
     RunCommandJob::RunCommandInfo info;
     if (str.length() > 1) {
-        const QString newStr = str.mid(1);
+        const QString newStr = str.sliced(1);
         QStringList lst = newStr.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-        const int numberElement = lst.count();
         info.commandName = lst.takeAt(0);
         info.roomId = QLatin1StringView(roomId);
         info.threadMessageId = QLatin1StringView(tmid);
-        if (numberElement > 1) {
+        if (!lst.isEmpty()) {
             info.params = lst.join(QLatin1Char(' '));
         }
+        if (forceUuid.isEmpty()) {
+            info.triggerId = QString::fromLatin1(QUuid::createUuid().toByteArray(QUuid::Id128));
+        } else {
+            info.triggerId = forceUuid;
+        }
     }
     return info;
 }
@@ -124,11 +135,11 @@ bool RunCommandJob::RunCommandInfo::isValid() const
 
 QDebug operator<<(QDebug d, const RunCommandJob::RunCommandInfo &t)
 {
-    d << " commandName " << t.commandName;
-    d << " roomId " << t.roomId;
-    d << " threadMessageId " << t.threadMessageId;
-    d << " triggerId " << t.triggerId;
-    d << " params " << t.params;
+    d.space() << "commandName" << t.commandName;
+    d.space() << "roomId" << t.roomId;
+    d.space() << "threadMessageId" << t.threadMessageId;
+    d.space() << "triggerId" << t.triggerId;
+    d.space() << "params" << t.params;
     return d;
 }
 
