@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "changearchivationstatejob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 ChangeArchivationStateJob::ChangeArchivationStateJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -37,11 +37,11 @@ void ChangeArchivationStateJob::onPostRequestResponse(const QString &replyErrorS
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("ChangeArchivationStateJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("ChangeArchivationStateJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT changeArchivationStateDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("ChangeArchivationStateJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("ChangeArchivationStateJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
