@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "uploadfilejob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -17,6 +16,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QMimeDatabase>
 #include <QNetworkReply>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 
 UploadFileJob::UploadFileJob(QObject *parent)
@@ -134,7 +134,7 @@ void UploadFileJob::slotUploadFinished()
         const QJsonDocument replyJson = convertToJsonDocument(reply);
         const QJsonObject replyObject = replyJson.object();
         if (replyObject.value("success"_L1).toBool()) {
-            addLoggerInfo(QByteArrayLiteral("UploadFileJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+            addLoggerInfo("UploadFileJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         } else {
             if (reply->error() != QNetworkReply::NoError) {
                 if (mReply->error() == QNetworkReply::NetworkSessionFailedError) {
@@ -147,7 +147,7 @@ void UploadFileJob::slotUploadFinished()
                 Q_EMIT failed(mReply->errorString() + QLatin1Char('\n') + errorStr(replyObject));
             } else {
                 emitFailedMessage(reply->errorString(), replyObject);
-                addLoggerWarning(QByteArrayLiteral("UploadFileJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+                addLoggerWarning("UploadFileJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
             }
         }
         reply->deleteLater();
