@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "videoconferencelistjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -14,6 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QUrlQuery>
 
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 VideoConferenceListJob::VideoConferenceListJob(QObject *parent)
     : RestApiAbstractJob(parent)
 {
@@ -47,7 +47,7 @@ bool VideoConferenceListJob::start()
     }
     submitGetRequest();
 
-    addStartRestApiInfo(QByteArrayLiteral("VideoConferenceListJob: Ask for capabilities"));
+    addStartRestApiInfo("VideoConferenceListJob: Ask for capabilities"_ba);
     return true;
 }
 
@@ -56,11 +56,11 @@ void VideoConferenceListJob::onGetRequestResponse(const QString &replyErrorStrin
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("VideoConferenceListJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("VideoConferenceListJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT videoConferenceInfoDone(replyObject);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("VideoConferenceListJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("VideoConferenceListJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
