@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,7 +20,9 @@ public:
 
     void setApplicationId(const QByteArray &appId);
 
-    void setApplicationInstalled(bool state);
+    void setShowLogAndSettingsInfo(bool state);
+
+    void setShowVersionInfo(bool state);
 
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void readConfig();
