@@ -1,20 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "applicationssettingslistview.h"
+#include "applicationspermissiondialog.h"
 #include "applicationssettingsaskapplicationdialog.h"
 #include "applicationssettingsdelegate.h"
 #include "applicationssettingsdescriptiondialog.h"
+#include "apps/appupdateinfojob.h"
 #include "apps/notifyadminsappsjob.h"
 #include "connection.h"
-#include "model/appsmarketplacefilterproxymodel.h"
 #include "model/appsmarketplacemodel.h"
 #include "rocketchataccount.h"
 #include "ruqolawidgets_debug.h"
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPointer>
@@ -73,6 +75,28 @@ void ApplicationsSettingsListView::slotCustomContextMenuRequested(const QPoint &
                     });
                 }
             }
+            if (index.data(AppsMarketPlaceModel::Installed).toBool()) {
+                if (mRocketChatAccount->isAdministrator()) {
+                    menu.addSeparator();
+                    menu.addAction(i18nc("@action", "Uninstall"), this, [this, index]() {
+                        slotUninstallApplication(index);
+                    });
+
+                    const AppsMarketPlaceInstalledInfo::Status appsStatus =
+                        index.data(AppsMarketPlaceModel::Status).value<AppsMarketPlaceInstalledInfo::Status>();
+                    if (appsStatus == AppsMarketPlaceInstalledInfo::Status::ManuallyEnabled) {
+                        menu.addSeparator();
+                        menu.addAction(i18nc("@action", "Disable"), this, [this, index]() {
+                            slotChangeStatusApplication(index, "manually_disabled"_L1);
+                        });
+                    } else {
+                        menu.addSeparator();
+                        menu.addAction(i18nc("@action", "Enable"), this, [this, index]() {
+                            slotChangeStatusApplication(index, "manually_enabled"_L1);
+                        });
+                    }
+                }
+            }
 
             if (mApplicationsSettingsListDelegate->hasSelection()) {
                 menu.addSeparator();
@@ -98,6 +122,11 @@ QString ApplicationsSettingsListView::selectedText() const
     return mApplicationsSettingsListDelegate->selectedText();
 }
 
+bool ApplicationsSettingsListView::hasSelection() const
+{
+    return mApplicationsSettingsListDelegate->hasSelection();
+}
+
 QString ApplicationsSettingsListView::selectedText(const QModelIndex &index)
 {
     QString messageText = selectedText();
@@ -140,10 +169,65 @@ void ApplicationsSettingsListView::setIsPrivate(bool isPrivate)
     mAppsMarketPlaceFilterProxyModel->setIsPrivate(isPrivate);
 }
 
+void ApplicationsSettingsListView::slotUninstallApplication(const QModelIndex &index)
+{
+    if (KMessageBox::questionTwoActions(this,
+                                        i18n("Do you want to uninstall this application?"),
+                                        i18nc("@title:window", "Uninstall Application"),
+                                        KStandardGuiItem::remove(),
+                                        KStandardGuiItem::cancel())
+        == KMessageBox::ButtonCode::PrimaryAction) {
+        auto job = new RocketChatRestApi::AppUpdateInfoJob(this);
+        RocketChatRestApi::AppUpdateInfoJob::AppUpdateInfo info;
+        info.mAppInfoType = RocketChatRestApi::AppUpdateInfoJob::AppInfoType::Apps;
+        info.mAppMode = RocketChatRestApi::AppUpdateInfoJob::AppMode::Delete;
+        info.mAppsId = index.data(AppsMarketPlaceModel::AppId).toByteArray();
+        job->setAppUpdateInfo(info);
+        mRocketChatAccount->restApi()->initializeRestApiJob(job);
+        if (!job->start()) {
+            qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start appUpdateInfoDone";
+        }
+    }
+}
+
+void ApplicationsSettingsListView::slotChangeStatusApplication(const QModelIndex &index, const QString &status)
+{
+    auto job = new RocketChatRestApi::AppUpdateInfoJob(this);
+    RocketChatRestApi::AppUpdateInfoJob::AppUpdateInfo info;
+    info.mAppInfoType = RocketChatRestApi::AppUpdateInfoJob::AppInfoType::Status;
+    info.mAppMode = RocketChatRestApi::AppUpdateInfoJob::AppMode::Post;
+    info.mAppsId = index.data(AppsMarketPlaceModel::AppId).toByteArray();
+    info.mStatus = status;
+
+    job->setAppUpdateInfo(info);
+    mRocketChatAccount->restApi()->initializeRestApiJob(job);
+    connect(job, &RocketChatRestApi::AppUpdateInfoJob::appUpdateInfoDone, this, [this]() {
+        Q_EMIT refreshListApplications();
+    });
+    if (!job->start()) {
+        qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start appUpdateInfoDone";
+    }
+}
+
 void ApplicationsSettingsListView::slotInstallApplication(const QModelIndex &index)
 {
-    qCWarning(RUQOLAWIDGETS_LOG) << "ApplicationsSettingsListView::slotInstallApplication not implemented yet.";
-    // TODO
+    QPointer<ApplicationsPermissionDialog> dlg = new ApplicationsPermissionDialog(this);
+    const QString permissions = index.data(AppsMarketPlaceModel::ApplicationPermissions).toString();
+    dlg->setApplicationPermission(permissions);
+    if (dlg->exec()) {
+        auto job = new RocketChatRestApi::AppUpdateInfoJob(this);
+        RocketChatRestApi::AppUpdateInfoJob::AppUpdateInfo info;
+        info.mAppInfoType = RocketChatRestApi::AppUpdateInfoJob::AppInfoType::Apps;
+        info.mAppMode = RocketChatRestApi::AppUpdateInfoJob::AppMode::Post;
+        info.mAppsId = index.data(AppsMarketPlaceModel::AppId).toByteArray();
+        info.mAppVersion = index.data(AppsMarketPlaceModel::AppVersion).toString();
+        job->setAppUpdateInfo(info);
+        mRocketChatAccount->restApi()->initializeRestApiJob(job);
+        if (!job->start()) {
+            qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start appUpdateInfoDone";
+        }
+    }
+    delete dlg;
 }
 
 void ApplicationsSettingsListView::slotAskApplication(const QModelIndex &index)
@@ -163,7 +247,7 @@ void ApplicationsSettingsListView::slotAskApplication(const QModelIndex &index)
             job->setInfo(info);
             mRocketChatAccount->restApi()->initializeRestApiJob(job);
             connect(job, &RocketChatRestApi::NotifyAdminsAppsJob::notifyAdminsAppsDone, this, [](const QJsonObject &obj) {
-                qDebug() << " obj " << obj;
+                qDebug() << "NotifyAdminsAppsJob: obj " << obj;
             });
             if (!job->start()) {
                 qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start NotifyAdminsAppsJob";
@@ -180,7 +264,12 @@ void ApplicationsSettingsListView::slotShowApplicationDescription(const QModelIn
     const QByteArray appId = index.data(AppsMarketPlaceModel::AppId).toByteArray();
     dlg.setDescription(description);
     dlg.setApplicationId(appId);
-    dlg.setApplicationInstalled(index.data(AppsMarketPlaceModel::Installed).toBool());
+
+    const bool showLogAndSettings = mRocketChatAccount->isAdministrator() && index.data(AppsMarketPlaceModel::Installed).toBool()
+        && !index.data(AppsMarketPlaceModel::RequestedApps).toBool();
+    const bool showVersion = mRocketChatAccount->isAdministrator() && !index.data(AppsMarketPlaceModel::Private).toBool();
+    dlg.setShowLogAndSettingsInfo(showLogAndSettings);
+    dlg.setShowVersionInfo(showVersion);
     dlg.exec();
 }
 
