@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,6 +28,8 @@ public:
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void slotFilterChanged();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotSortingChanged();
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotRefreshListApplications();
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotRefreshCountApplications();
     RocketChatAccount *const mCurrentRocketChatAccount;
     ApplicationsSettingsSearchWidget *const mApplicationsSettingsSearchWidget;
     ApplicationsSettingsListView *const mApplicationsSettingsListView;
