@@ -1,9 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "listattachmentdelegate.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "common/delegatepaintutil.h"
 #include "common/delegateutil.h"
 #include "model/filesforroommodel.h"
@@ -80,6 +82,16 @@ void ListAttachmentDelegate::paint(QPainter *painter, const QStyleOptionViewItem
     painter->restore();
 }
 
+void ListAttachmentDelegate::saveAttachment(const QStyleOptionViewItem &option, const File *file)
+{
+    auto parentWidget = const_cast<QWidget *>(option.widget);
+    const QString fileName = DelegateUtil::querySaveFileName(parentWidget, i18nc("@title:window", "Save Attachment"), QUrl(file->url()));
+
+    if (!fileName.isEmpty()) {
+        mRocketChatAccount->downloadFile(file->url(), QUrl::fromLocalFile(fileName));
+    }
+}
+
 bool ListAttachmentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
     const QEvent::Type eventType = event->type();
@@ -91,12 +103,7 @@ bool ListAttachmentDelegate::editorEvent(QEvent *event, QAbstractItemModel *mode
         const Layout layout = doLayout(option, index);
 
         if (layout.downloadAttachmentRect.contains(mev->pos())) {
-            auto parentWidget = const_cast<QWidget *>(option.widget);
-            const QString fileName = DelegateUtil::querySaveFileName(parentWidget, i18nc("@title:window", "Save Attachment"), QUrl(file->url()));
-
-            if (!fileName.isEmpty()) {
-                mRocketChatAccount->downloadFile(file->url(), QUrl::fromLocalFile(fileName));
-            }
+            saveAttachment(option, file);
             return true;
         }
         if (layout.deleteAttachmentRect.contains(mev->pos()) && (file->userId() == mRocketChatAccount->userId())) {
@@ -109,8 +116,16 @@ bool ListAttachmentDelegate::editorEvent(QEvent *event, QAbstractItemModel *mode
                                                    KStandardGuiItem::cancel())) {
                 const QByteArray fileId = file->fileId();
                 Q_EMIT deleteAttachment(fileId);
-                // TODO
-                // appid.rocketChatAccount.deleteFileMessage(appid.selectedRoomID, fileId, appid.selectedRoom.channelType)
+            }
+            return true;
+        }
+    } else if (eventType == QEvent::MouseButtonDblClick) {
+        const File *file = index.data(FilesForRoomModel::FilePointer).value<File *>();
+        if (file) {
+            if (file->typeGroup() == "image"_L1) {
+                Q_EMIT showImage(file->fileId());
+            } else {
+                saveAttachment(option, file);
             }
             return true;
         }
