@@ -1,22 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
-#include <QGraphicsView>
 #include <QWidget>
 
+#include "attachments/fileattachments.h"
 #include "libruqolawidgets_private_export.h"
 
-class QLabel;
 class QSlider;
 class QDoubleSpinBox;
-class QMovie;
-class ImageGraphicsView;
+class ShowImageGraphicsView;
 class RocketChatAccount;
+class ShowImagePrevNextImageWidget;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT ShowImageWidget : public QWidget
 {
     Q_OBJECT
@@ -29,6 +28,14 @@ public:
         bool needToDownloadBigImage = false;
     };
 
+    struct ImageListInfo {
+        [[nodiscard]] ImageInfo imageFromIndex(int index, RocketChatAccount *account) const;
+        FileAttachments imageAttachments;
+        QByteArray fileId;
+        QByteArray roomId;
+        int index = 0;
+    };
+
     explicit ShowImageWidget(RocketChatAccount *account, QWidget *parent = nullptr);
     ~ShowImageWidget() override;
 
@@ -40,70 +47,25 @@ public:
     void copyImage();
     void copyLocation();
 
+    void showImages(const QByteArray &fileId, const QByteArray &roomId, int offset = 0);
+
 protected:
     void keyPressEvent(QKeyEvent *event) override;
 
 private:
+    LIBRUQOLAWIDGETS_NO_EXPORT void updateButtons();
     LIBRUQOLAWIDGETS_NO_EXPORT void updateRanges();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotFileDownloaded(const QString &filePath, const QUrl &cacheImageUrl);
-    ImageGraphicsView *const mImageGraphicsView;
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotShowPreviousImage();
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotShowNextImage();
+    ImageListInfo mImageListInfo;
+    ShowImageGraphicsView *const mImageGraphicsView;
     QWidget *const mZoomControls;
     QDoubleSpinBox *const mZoomSpin;
     QSlider *const mSlider;
+    ShowImagePrevNextImageWidget *const mShowImagePrevNextImageWidget;
     RocketChatAccount *const mRocketChatAccount;
 };
 Q_DECLARE_TYPEINFO(ShowImageWidget::ImageInfo, Q_RELOCATABLE_TYPE);
-
-class LIBRUQOLAWIDGETS_TESTS_EXPORT ImageGraphicsView : public QGraphicsView
-{
-    Q_OBJECT
-public:
-    explicit ImageGraphicsView(RocketChatAccount *account, QWidget *parent = nullptr);
-    ~ImageGraphicsView() override;
-
-    void clearContents();
-
-    [[nodiscard]] qreal minimumZoom() const;
-    [[nodiscard]] qreal maximumZoom() const;
-
-    [[nodiscard]] qreal zoom() const;
-    void setZoom(qreal zoom, QPointF centerPos = {});
-
-    void setImageInfo(const ShowImageWidget::ImageInfo &info);
-    [[nodiscard]] const ShowImageWidget::ImageInfo &imageInfo() const;
-
-    void updatePixmap(const QPixmap &pix, const QString &path);
-    [[nodiscard]] QPixmap pixmap() const;
-
-    void fitToView();
-
-protected:
-    void wheelEvent(QWheelEvent *e) override;
-
-Q_SIGNALS:
-    void zoomChanged(qreal zoom);
-    void minimumZoomChanged(qreal zoom);
-    void maximumZoomChanged(qreal zoom);
-
-private:
-    LIBRUQOLAWIDGETS_NO_EXPORT void zoomIn(QPointF centerPos = {});
-    LIBRUQOLAWIDGETS_NO_EXPORT void zoomOut(QPointF centerPos = {});
-    LIBRUQOLAWIDGETS_NO_EXPORT void updateRanges();
-    [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT QSize originalImageSize() const;
-
-    QString mImagePath;
-
-    QSize mOriginalMovieSize;
-    QScopedPointer<QMovie> mMovie;
-    ShowImageWidget::ImageInfo mImageInfo;
-
-    QGraphicsProxyWidget *mGraphicsProxyWidget = nullptr;
-    QGraphicsPixmapItem *mGraphicsPixmapItem = nullptr;
-    QLabel *const mAnimatedLabel;
-    RocketChatAccount *const mRocketChatAccount;
-
-    qreal mMinimumZoom;
-    qreal mMaximumZoom;
-    bool mIsUpdatingZoom = false;
-};
 LIBRUQOLAWIDGETS_EXPORT QDebug operator<<(QDebug d, const ShowImageWidget::ImageInfo &t);
+LIBRUQOLAWIDGETS_EXPORT QDebug operator<<(QDebug d, const ShowImageWidget::ImageListInfo &t);
