@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "showlistmessagebasewidget.h"
-#include "model/listmessagesfilterproxymodel.h"
+#include "dialogs/searchmessagelinewidget.h"
 #include "room/messagelistview.h"
 #include <KLineEditEventHandler>
 
@@ -22,7 +22,7 @@
 
 ShowListMessageBaseWidget::ShowListMessageBaseWidget(RocketChatAccount *account, QWidget *parent)
     : QWidget(parent)
-    , mSearchMessageLineEdit(new QLineEdit(this))
+    , mSearchMessageLineWidget(new SearchMessageLineWidget(this))
     , mMessageListInfo(new QLabel(this))
     , mMessageListView(new MessageListView(account, MessageListView::Mode::Viewing, this))
 #if HAVE_TEXT_TO_SPEECH
@@ -33,12 +33,9 @@ ShowListMessageBaseWidget::ShowListMessageBaseWidget(RocketChatAccount *account,
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins({});
 
-    mSearchMessageLineEdit->setObjectName(QStringLiteral("mSearchMessageLineEdit"));
-    mSearchMessageLineEdit->setClearButtonEnabled(true);
-    KLineEditEventHandler::catchReturnKey(mSearchMessageLineEdit);
-    mSearchMessageLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search messages…"));
-    connect(mSearchMessageLineEdit, &QLineEdit::textChanged, this, &ShowListMessageBaseWidget::slotSearchMessageTextChanged);
-    mainLayout->addWidget(mSearchMessageLineEdit);
+    mSearchMessageLineWidget->setObjectName(QStringLiteral("mSearchMessageLineWidget"));
+    connect(mSearchMessageLineWidget, &SearchMessageLineWidget::textChanged, this, &ShowListMessageBaseWidget::slotSearchMessageTextChanged);
+    mainLayout->addWidget(mSearchMessageLineWidget);
 
     mMessageListInfo->setObjectName(QStringLiteral("mMessageListInfo"));
     mMessageListInfo->setTextFormat(Qt::RichText);
@@ -71,7 +68,11 @@ ShowListMessageBaseWidget::~ShowListMessageBaseWidget()
     }
 }
 
-void ShowListMessageBaseWidget::setModel(ListMessagesFilterProxyModel *model)
+void ShowListMessageBaseWidget::setFilteringByType(ListMessagesFilterProxyModel::FilteringByType type)
+{
+    mModel->setFilteringByType(type);
+}
+void ShowListMessageBaseWidget::setFilterProxyModel(ListMessagesFilterProxyModel *model)
 {
     mModel = model;
     mMessageListView->setModel(model);
@@ -91,6 +92,11 @@ void ShowListMessageBaseWidget::setRoom(Room *room)
     mMessageListView->setRoom(room);
 }
 
+void ShowListMessageBaseWidget::addMessageLineWidget(QWidget *w)
+{
+    mSearchMessageLineWidget->addMessageLineWidget(w);
+}
+
 void ShowListMessageBaseWidget::updateLabel()
 {
     if (mModel->loadMoreListMessagesInProgress()) {
