@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ QString ImportExportUtils::databasePath()
 
 QDebug operator<<(QDebug d, const ImportExportUtils::AccountImportExportInfo &t)
 {
-    d << "path " << t.path;
-    d << "accountName " << t.accountName;
+    d.space() << "path " << t.path;
+    d.space() << "accountName " << t.accountName;
     return d;
 }
