@@ -1,10 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "usersinroomcomboboxtest.h"
+#include "model/usersforroomfilterproxymodel.h"
 #include "room/usersinroomcombobox.h"
 #include <QTest>
 QTEST_MAIN(UsersInRoomComboBoxTest)
@@ -15,10 +16,9 @@ UsersInRoomComboBoxTest::UsersInRoomComboBoxTest(QObject *parent)
 
 void UsersInRoomComboBoxTest::shouldHaveDefaultValues()
 {
-    UsersInRoomComboBox w;
+    UsersInRoomComboBox w(false);
     QVERIFY(w.count() > 0);
-    QVERIFY(w.currentData().toString().isEmpty());
-    // TODO
+    QCOMPARE(w.currentData().value<UsersForRoomFilterProxyModel::FilterUserType>(), UsersForRoomFilterProxyModel::FilterUserType::All);
 }
 
 #include "moc_usersinroomcomboboxtest.cpp"
