@@ -5,7 +5,6 @@
 */
 
 #include "messageattachmentdelegatehelperfile.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "common/delegatepaintutil.h"
 #include "common/delegateutil.h"
@@ -32,6 +31,7 @@ using namespace Qt::Literals::StringLiterals;
 //  Name <download icon>
 //  Description
 
+using namespace Qt::Literals::StringLiterals;
 MessageAttachmentDelegateHelperFile::MessageAttachmentDelegateHelperFile(RocketChatAccount *account, QListView *view, TextSelectionImpl *textSelectionImpl)
     : MessageAttachmentDelegateHelperBase(account, view, textSelectionImpl)
     , mDownloadIcon(QIcon::fromTheme(QStringLiteral("cloud-download")))
@@ -137,7 +137,7 @@ static void runApplication(const KService::Ptr &offer, const QString &link, QWid
     const QUrl fileUrl = QUrl::fromLocalFile(tempFile);
 
     const QUrl downloadUrl = account->urlForLink(link);
-    auto *job = account->restApi()->downloadFile(downloadUrl, fileUrl, QByteArrayLiteral("text/plain"));
+    auto *job = account->restApi()->downloadFile(downloadUrl, fileUrl, "text/plain"_ba);
     QObject::connect(job, &RocketChatRestApi::DownloadFileJob::downloadFileDone, widget, [offer, widget](const QUrl &, const QUrl &localFileUrl) {
         auto job = new KIO::ApplicationLauncherJob(offer); // asks the user if offer is nullptr
         job->setUrls({localFileUrl});
