@@ -88,7 +88,7 @@ void MessageAttachmentDelegateHelperImage::draw(const MessageAttachment &msgAtta
         }
     } else {
         if (layout.imagePreviewPath.isEmpty()) {
-            qCWarning(RUQOLAWIDGETS_LOG) << "Image path is empty! It's a bug ???" << msgAttach;
+            // Not a bug, it's just that the image is currently being downloaded by RocketChatCache::downloadFileFromServer
         } else {
             qCWarning(RUQOLAWIDGETS_LOG) << "Invalid image (Qt bug or others). It will not render: " << layout.imagePreviewPath;
             downloadIcon.paint(painter, layout.downloadButtonRect.translated(messageRect.topLeft()));
