@@ -1,12 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagelistview.h"
 
+#include "actionbuttons/actionbuttonsmanager.h"
+#include "actionbuttons/actionbuttonutil.h"
 #include "administratordialog/moderationconsole/moderationmessageinfodialog.h"
+#include "autogenerateui/autogenerateinteractionutil.h"
 #include "chat/deletemessagejob.h"
 #include "chat/followmessagejob.h"
 #include "chat/pinmessagejob.h"
@@ -16,6 +19,7 @@
 #include "chat/unfollowmessagejob.h"
 
 #include "forwardmessage/forwardmessagedialog.h"
+#include "misc/appsuiinteractionjob.h"
 #include "moderation/moderationdismissreportsjob.h"
 
 #include "connection.h"
@@ -33,6 +37,8 @@
 #include "subscriptions/markroomasunreadjob.h"
 #include "threadwidget/threadmessagedialog.h"
 
+#include "actionbuttons/actionbutton.h"
+
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -275,13 +281,19 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
     mMessageListDelegate->attachmentContextMenu(options, index, info, &menu);
     const bool isNotOwnerOfMessage = (index.data(MessagesModel::UserId).toByteArray() != mCurrentRocketChatAccount->userId());
 
-    auto copyAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("@action", "Copy Message"), &menu);
+    auto copyAction = new QAction(&menu);
+    copyAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
+    if (hasSelection()) {
+        copyAction->setText(i18nc("@action", "Copy Selection"));
+    } else {
+        copyAction->setText(i18nc("@action", "Copy Message"));
+    }
     copyAction->setShortcut(QKeySequence::Copy);
     connect(copyAction, &QAction::triggered, this, [this, index]() {
         copyMessageToClipboard(index);
     });
     QAction *setPinnedMessage = nullptr;
-    if (mCurrentRocketChatAccount->allowMessagePinningEnabled() && mRoom && mRoom->allowToPinMessage()) {
+    if (mCurrentRocketChatAccount->ruqolaServerConfig()->allowMessagePinningEnabled() && mRoom && mRoom->allowToPinMessage()) {
         const bool isPinned = index.data(MessagesModel::Pinned).toBool();
         setPinnedMessage =
             new QAction(QIcon::fromTheme(QStringLiteral("pin")), isPinned ? i18nc("@action", "Unpin Message") : i18nc("@action", "Pin Message"), &menu);
@@ -290,7 +302,7 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
         });
     }
     QAction *setAsFavoriteAction = nullptr;
-    if (mCurrentRocketChatAccount->allowMessageStarringEnabled()) {
+    if (mCurrentRocketChatAccount->ruqolaServerConfig()->allowMessageStarringEnabled()) {
         const bool isStarred = index.data(MessagesModel::Starred).toBool();
         setAsFavoriteAction = new QAction(QIcon::fromTheme(QStringLiteral("favorite")),
                                           isStarred ? i18nc("@action", "Remove as Favorite") : i18nc("@action", "Set as Favorite"),
@@ -412,7 +424,7 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
 
     auto threadInfoActions = [&]() -> QList<QAction *> {
         QList<QAction *> listActions;
-        if (mCurrentRocketChatAccount->threadsEnabled()) {
+        if (mCurrentRocketChatAccount->ruqolaServerConfig()->threadsEnabled()) {
             const QString threadMessageId = index.data(MessagesModel::ThreadMessageId).toString();
             const int threadMessageCount = index.data(MessagesModel::ThreadCount).toInt();
             if (!threadMessageId.isEmpty() || threadMessageCount > 0) {
@@ -668,6 +680,47 @@ void MessageListView::contextMenuEvent(QContextMenuEvent *event)
     if (Ruqola::self()->debug()) {
         addDebugMenu(menu, index);
     }
+    if (mCurrentRocketChatAccount) {
+        ActionButton::FilterActionInfo filterInfo;
+        filterInfo.buttonContext = ActionButton::ButtonContext::MessageAction;
+        filterInfo.roomTypeFilter = ActionButtonUtil::convertRoomTypeToActionButtonRoomTypeFilter(mRoom);
+        const QList<ActionButton> actionButtons = mCurrentRocketChatAccount->actionButtonsManager()->actionButtonsFromFilterActionInfo(filterInfo);
+        if (!actionButtons.isEmpty()) {
+            const QString lang = QLocale().name();
+            auto actSeparator = new QAction(this);
+            actSeparator->setSeparator(true);
+            menu.addAction(actSeparator);
+            for (const auto &actionButton : actionButtons) {
+                auto act = new QAction(this);
+                const QString translateIdentifier = ActionButtonUtil::generateTranslateIdentifier(actionButton);
+                const QString appId = QString::fromLatin1(actionButton.appId());
+                const QByteArray roomId = mRoom->roomId();
+                act->setText(mCurrentRocketChatAccount->getTranslatedIdentifier(lang, translateIdentifier));
+                connect(act, &QAction::triggered, this, [this, actionButton, appId, roomId, message]() {
+                    auto job = new RocketChatRestApi::AppsUiInteractionJob(this);
+                    RocketChatRestApi::AppsUiInteractionJob::AppsUiInteractionJobInfo info;
+                    info.methodName = appId;
+                    AutoGenerateInteractionUtil::ActionMessageInfo actionMessageInfo;
+                    actionMessageInfo.actionId = actionButton.actionId();
+                    actionMessageInfo.triggerId = QUuid::createUuid().toByteArray(QUuid::Id128);
+                    actionMessageInfo.roomId = roomId;
+                    actionMessageInfo.messageId = message->messageId();
+                    info.messageObj = AutoGenerateInteractionUtil::createMessageActionButton(actionMessageInfo);
+                    job->setAppsUiInteractionJobInfo(info);
+
+                    mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
+                    connect(job, &RocketChatRestApi::AppsUiInteractionJob::appsUiInteractionDone, this, [this](const QJsonObject &replyObject) {
+                        Q_EMIT uiInteractionRequested(replyObject);
+                    });
+                    if (!job->start()) {
+                        qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start AppsUiInteractionJob job";
+                    }
+                });
+                menu.addAction(act);
+            }
+        }
+    }
+
     if (!menu.actions().isEmpty()) {
         menu.exec(event->globalPos());
     }
@@ -827,7 +880,7 @@ void MessageListView::slotShowFullThread(const QModelIndex &index)
             threadMessagePreview = index.data(MessagesModel::MessageConvertedText).toString();
         }
     }
-    auto dlg = new ThreadMessageDialog(mCurrentRocketChatAccount, this);
+    auto dlg = new ThreadMessageDialog(mCurrentRocketChatAccount, Ruqola::self()->parentWidget());
     ThreadMessageWidget::ThreadMessageInfo info;
     info.threadMessageId = messageId;
     info.threadMessagePreview = threadMessagePreview;
@@ -939,6 +992,11 @@ void MessageListView::slotStartDiscussion(const QModelIndex &index)
     Q_EMIT createNewDiscussion(messageId, message);
 }
 
+bool MessageListView::hasSelection() const
+{
+    return mMessageListDelegate->hasSelection();
+}
+
 QString MessageListView::selectedText(const QModelIndex &index)
 {
     QString message = mMessageListDelegate->selectedText();
